@@ -1,6 +1,6 @@
 # -*- coding: iso-8859-15 -*-
 # Copyright (C) 2002  Tobias Klausmann
-# Modified by Jerome Alet
+# Modifications Copyright (C) 2002 by Jerome Alet
 # 
 # Code contributed by:
 # Jerome Alet 
@@ -38,9 +38,9 @@ import urllib2
 
 __author__ = "klausman-pymetar@schwarzvogel.de"
 
-__version__ = "0.8"
+__version__ = "0.10"
 
-__doc__ = """Pymetar v%s (c) 2002-2004 Tobias Klausman
+__doc__ = """Pymetar v%s (c) 2002-2004 Tobias Klausmann
 
 Pymetar is a python module and command line tool designed to fetch Metar
 reports from the NOAA (http://www.noaa.gov) and allow access to the
@@ -74,6 +74,10 @@ class EmptyIDException(Exception):
     def __init__(self, args=None):
         self.args=args
 
+class NetworkException(Exception):
+    def __init__(self, args=None):
+        self.args=args
+
 # What a boring list to type !
 #
 # It seems the NOAA doesn't want to return plain text, but considering the
@@ -476,13 +480,15 @@ class WeatherReport:
         """
         Return visibility in km.
         """
-        return self.vis
+        if self.vis is not None:
+            return self.vis / 1.609344
 
     def getVisibilityMiles(self):
         """
         Return visibility in miles.
         """
-        return self.vis / 1.609344
+        if self.vis is not None:
+            return self.vis / 1.609344
 
     def getHumidity(self):
         """
